@@ -4,6 +4,7 @@ try:
 except:
     memcache_imported = False
 
+
 class Cache(object):
     """The base Cache class.
     Stores the cached data in memory.
@@ -34,6 +35,9 @@ class Cache(object):
         has_data = hasattr(self, name)
         return has_data
 
+    def clear(self, name):
+        return delattr(self, name)
+
 
 class Memcache(Cache):
     """Stores the cached data in memcache."""
